import logging
import sys
import psycopg2 as pg
from pycapo import CapoConfig
from sqlalchemy.engine import Connection

logger = logging.getLogger("ws_metrics")
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))


class MDDBConnector:
    """Use this connection to interrogate the archive"""

    def __init__(self):
        self.connection = self._connect_to_db()

    @staticmethod
    def _connect_to_db() -> Connection:
        """
        Establish a DB connection

        :return:
        """
        settings = CapoConfig().settings("metadataDatabase")

        host_slash_db = settings["jdbcUrl"][len("jdbc:postgresql://") :]
        host, dbname = host_slash_db.split("/")
        port = 5432
        if ":" in host:
            host, port = host.split(":")
        try:
            conn = pg.connect(
                host=host,
                port=port,
                database=dbname,
                user=settings.jdbcUsername,
                password=settings.jdbcPassword,
            )
            return conn
        except Exception as exc:
            logger.error(f"Unable to connect to database: {exc}")
            raise exc

    def cursor(self):
        return self.connection.cursor()

    def close(self):
        self.connection.close()
